==> haskell-smtlib-1.0.8-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-smtlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smtLib
version: 1.0.8
id: smtLib-1.0.8-Hes5OESP1193Ld647kbA9w
key: smtLib-1.0.8-Hes5OESP1193Ld647kbA9w
license: BSD3
maintainer: iavor.diatchki@gmail.com
synopsis: A library for working with the SMTLIB format.
description:
    A library for working with the SMTLIB format.
category: SMT
author: Iavor S. Diatchki
exposed: True
indefinite: False
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int
hidden-modules: SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
abi: 1999e850aee756ca61d7043fff5627c8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/smtLib-1.0.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/smtLib-1.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/smtLib-1.0.8
hs-libraries: HSsmtLib-1.0.8-Hes5OESP1193Ld647kbA9w
depends:
    base-4.10.1.0 pretty-1.1.3.3
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
haddock-interfaces: /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html: /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smtlib-1.0.9-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-smtlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smtLib
version: 1.0.9
id: smtLib-1.0.9-6vwf9of4gDxCqBtFifNi4C
key: smtLib-1.0.9-6vwf9of4gDxCqBtFifNi4C
license: BSD-3-Clause
maintainer: iavor.diatchki@gmail.com
author: Iavor S. Diatchki
synopsis: A library for working with the SMTLIB format.
description:
    A library for working with the SMTLIB format.
category: SMT
abi: 7121b09caabe85d6e62d698cf55ea062
exposed: True
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int
hidden-modules: SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
import-dirs: /usr/lib/ghc-8.4.2/site-local/smtLib-1.0.9
library-dirs: /usr/lib/ghc-8.4.2/site-local/smtLib-1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/smtLib-1.0.9
hs-libraries: HSsmtLib-1.0.9-6vwf9of4gDxCqBtFifNi4C
depends:
    base-4.11.1.0 pretty-1.1.3.6
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             pretty-1.1.3.6=003e48b94caa84f26c31da01b81a0320
haddock-interfaces: /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html: /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
